@@ -1,6 +1,7 @@
 /* This file is part of the KDE libraries
  *
  * Copyright (c) 2011 Aurélien Gâteau <agateau@kde.org>
+ * Copyright (c) 2014 Dominik Haumann <dhaumann@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -82,15 +83,15 @@ void KMessageWidgetPrivate::init(KMessageWidget *q_ptr)
     textLabel = new QLabel(content);
     textLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     textLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
-    QObject::connect(textLabel, SIGNAL(linkActivated(QString)), q, SIGNAL(linkActivated(QString)));
-    QObject::connect(textLabel, SIGNAL(linkHovered(QString)), q, SIGNAL(linkHovered(QString)));
+    QObject::connect(textLabel, &QLabel::linkActivated, q, &KMessageWidget::linkActivated);
+    QObject::connect(textLabel, &QLabel::linkHovered, q, &KMessageWidget::linkHovered);
 
     QAction *closeAction = new QAction(q);
-    closeAction->setText(q->tr("&Close"));
-    closeAction->setToolTip(q->tr("Close message"));
+    closeAction->setText(KMessageWidget::tr("&Close"));
+    closeAction->setToolTip(KMessageWidget::tr("Close message"));
     closeAction->setIcon(q->style()->standardIcon(QStyle::SP_DialogCloseButton));
 
-    QObject::connect(closeAction, SIGNAL(triggered(bool)), q, SLOT(animatedHide()));
+    QObject::connect(closeAction, &QAction::triggered, q, &KMessageWidget::animatedHide);
 
     closeButton = new QToolButton(content);
     closeButton->setAutoRaise(true);
@@ -168,7 +169,8 @@ void KMessageWidgetPrivate::updateSnapShot()
     // window layouts to be activated. Calling this method from resizeEvent()
     // can lead to infinite recursion, see:
     // https://bugs.kde.org/show_bug.cgi?id=311336
-    contentSnapShot = QPixmap(content->size());
+    contentSnapShot = QPixmap(content->size() * q->devicePixelRatio());
+    contentSnapShot.setDevicePixelRatio(q->devicePixelRatio());
     contentSnapShot.fill(Qt::transparent);
     content->render(&contentSnapShot, QPoint(), QRegion(), QWidget::DrawChildren);
 }
@@ -186,9 +188,13 @@ void KMessageWidgetPrivate::slotTimeLineFinished()
         // We set the whole geometry here, because it may be wrong if a
         // KMessageWidget is shown right when the toplevel window is created.
         content->setGeometry(0, 0, q->width(), bestContentHeight());
+
+        // notify about finished animation
+        emit q->showAnimationFinished();
     } else {
-        // Hide
+        // hide and notify about finished animation
         q->hide();
+        emit q->hideAnimationFinished();
     }
 }
 
@@ -285,7 +291,7 @@ void KMessageWidget::setMessageType(KMessageWidget::MessageType type)
     border = darkShade(bg1);
 
     d->content->setStyleSheet(
-        QString(QLatin1String(".QFrame {"
+        QString::fromLatin1(".QFrame {"
                               "background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,"
                               "    stop: 0 %1,"
                               "    stop: 0.1 %2,"
@@ -295,7 +301,7 @@ void KMessageWidget::setMessageType(KMessageWidget::MessageType type)
                               "margin: %5px;"
                               "}"
                               ".QLabel { color: %6; }"
-                             ))
+                             )
         .arg(bg0.name())
         .arg(bg1.name())
         .arg(bg2.name())
@@ -399,6 +405,7 @@ void KMessageWidget::animatedShow()
 {
     if (!style()->styleHint(QStyle::SH_Widget_Animate, 0, this)) {
         show();
+        emit showAnimationFinished();
         return;
     }
 
@@ -423,6 +430,7 @@ void KMessageWidget::animatedHide()
 {
     if (!style()->styleHint(QStyle::SH_Widget_Animate, 0, this)) {
         hide();
+        emit hideAnimationFinished();
         return;
     }
 
@@ -439,6 +447,18 @@ void KMessageWidget::animatedHide()
     }
 }
 
+bool KMessageWidget::isHideAnimationRunning() const
+{
+    return (d->timeLine->direction() == QTimeLine::Backward)
+        && (d->timeLine->state() == QTimeLine::Running);
+}
+
+bool KMessageWidget::isShowAnimationRunning() const
+{
+    return (d->timeLine->direction() == QTimeLine::Forward)
+        && (d->timeLine->state() == QTimeLine::Running);
+}
+
 QIcon KMessageWidget::icon() const
 {
     return d->icon;
